RobotPy WPILib
==============

This repository contain a python implementation of wrappers for WPILib,
the library used to interface with hardware for the FIRST Robotics Competition. 
Teams can use this library to write their robot code in Python, a powerful dynamic
programming language.

**Note**: RobotPy is a community project and is not officially supported by
FIRST. Please see the [FAQ](https://robotpy.github.io/faq/) for more information.

Documentation
=============

All RobotPy documentation can be found at https://robotpy.readthedocs.io

Installation
============

Installation instructions can be found in the [RobotPy documentation](https://robotpy.readthedocs.io/en/latest/getting_started.html)


License
=======

See [LICENSE.txt](LICENSE.txt)

Contributors
============

RobotPy is a community project, and many people have contributed over the years
to make it what it is today. RobotPy's history can be found on our
[documentation site](https://robotpy.readthedocs.io/en/stable/faq.html#who-created-robotpy).
